@@ -21,9 +21,10 @@
 #include "BitMatrix.h"
 
 namespace ZXing {
-    
-	std::string ToString(const BitMatrix& matrix, char one = 'X', char zero = ' ', bool addSpace = true, bool printAsCString = false);
-	BitMatrix ParseBitMatrix(const std::string& str, char one = 'X', bool expectSpace = true);
-	void SaveAsPBM(const BitMatrix& matrix, const std::string filename, int quiteZone = 0);
+
+std::string ToString(const BitMatrix& matrix, char one = 'X', char zero = ' ', bool addSpace = true,
+					 bool printAsCString = false);
+BitMatrix ParseBitMatrix(const std::string& str, char one = 'X', bool expectSpace = true);
+void SaveAsPBM(const BitMatrix& matrix, const std::string filename, int quiteZone = 0);
 
 } // ZXing
