@@ -15,18 +15,21 @@
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
+
 #include "GenericGFPoly.h"
+
 #include <list>
 #include <vector>
 
 namespace ZXing {
 
+// public only for testing purposes
 class ReedSolomonEncoder
 {
 public:
 	explicit ReedSolomonEncoder(const GenericGF& field);
 
-	void encode(std::vector<int>& toEncode, int ecBytes);
+	void encode(std::vector<int>& message, int numECCodeWords);
 
 private:
 	const GenericGF* _field;
@@ -35,4 +38,12 @@ private:
 	const GenericGFPoly& buildGenerator(int degree);
 };
 
-} // ZXing
+/**
+ * @brief ReedSolomonEncode replaces the last numECCodeWords code words in message with error correction code words
+ */
+inline void ReedSolomonEncode(const GenericGF& field, std::vector<int>& message, int numECCodeWords)
+{
+	ReedSolomonEncoder(field).encode(message, numECCodeWords);
+}
+
+} // namespace ZXing
