@@ -15,11 +15,12 @@
 */
 
 #include "TextDecoder.h"
+
 #include "CharacterSet.h"
 #include "TextUtfEncoding.h"
-#include "textcodec/JPTextDecoder.h"
-#include "textcodec/GBTextDecoder.h"
 #include "textcodec/Big5TextDecoder.h"
+#include "textcodec/GBTextDecoder.h"
+#include "textcodec/JPTextDecoder.h"
 #include "textcodec/KRTextDecoder.h"
 
 #include <vector>
@@ -120,7 +121,7 @@ static const uint16_t SINGLE_BYTE_CODEPAGES[] = {
 	0x0101, 0x00E1, 0x00E2, 0x00E3, 0x00E4, 0x00E5, 0x00E6, 0x012F, 0x010D, 0x00E9, 0x0119, 0x00EB, 0x0117, 0x00ED, 0x00EE, 0x00EF,
 	0x00F0, 0x0146, 0x014D, 0x00F3, 0x00F4, 0x00F5, 0x00F6, 0x0169, 0x00F8, 0x0173, 0x00FA, 0x00FB, 0x00FC, 0x00FD, 0x00FE, 0x0138,
 
-	// ISO-8859-11
+	// ISO-8859-11 (extended with 9 CP874 codepoints in 0x80-9F range)
 	0x20AC, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0x2026, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD,
 	0xFFFD, 0x2018, 0x2019, 0x201C, 0x201D, 0x2022, 0x2013, 0x2014, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD, 0xFFFD,
 	0xFFFD, 0x0E01, 0x0E02, 0x0E03, 0x0E04, 0x0E05, 0x0E06, 0x0E07, 0x0E08, 0x0E09, 0x0E0A, 0x0E0B, 0x0E0C, 0x0E0D, 0x0E0E, 0x0E0F,
@@ -233,6 +234,7 @@ TextDecoder::Append(std::wstring& str, const uint8_t* bytes, size_t length, Char
 	case CharacterSet::Unknown:
 	case CharacterSet::ISO8859_1:
 	case CharacterSet::ASCII:
+	case CharacterSet::BINARY:
 	{
 		str.append(bytes, bytes + length);
 		break;
@@ -308,14 +310,14 @@ TextDecoder::Append(std::wstring& str, const uint8_t* bytes, size_t length, Char
 		KRTextDecoder::AppendEucKr(buf, bytes, length);
 		TextUtfEncoding::AppendUtf16(str, buf.data(), buf.size());
 		break;
-		break;
 	}
 	case CharacterSet::UnicodeBig:
 	{
-		str.reserve(str.length() + length / 2);
+		std::vector<uint16_t> buf;
 		for (size_t i = 0; i + 1 < length; i += 2) {
-			str.push_back((static_cast<wchar_t>(bytes[i]) << 8) + bytes[i + 1]);
+			buf.push_back((static_cast<uint16_t>(bytes[i]) << 8) | bytes[i + 1]);
 		}
+		TextUtfEncoding::AppendUtf16(str, buf.data(), buf.size());
 		break;
 	}
 	case CharacterSet::UTF8:
