@@ -16,19 +16,19 @@
 */
 
 #include "AZHighLevelEncoder.h"
+
 #include "AZEncodingState.h"
 #include "AZToken.h"
 #include "BitArray.h"
 #include "ZXContainerAlgorithms.h"
 
+#include <algorithm>
 #include <array>
 #include <cstdint>
-#include <algorithm>
 #include <list>
 #include <vector>
 
-namespace ZXing {
-namespace Aztec {
+namespace ZXing::Aztec {
 
 // Do not change these constants
 static const int MODE_UPPER = 0; // 5 bits
@@ -399,5 +399,4 @@ HighLevelEncoder::Encode(const std::string& text)
 	return ToBitArray(minState, text);
 }
 
-} // Aztec
-} // ZXing
+} // namespace ZXing::Aztec
