@@ -18,7 +18,12 @@
 
 #include "Reader.h"
 
+#include <string>
+
 namespace ZXing {
+
+class DecodeHints;
+
 namespace Aztec {
 
 /**
@@ -29,7 +34,12 @@ namespace Aztec {
 class Reader : public ZXing::Reader
 {
 public:
+	explicit Reader(const DecodeHints& hints);
 	Result decode(const BinaryBitmap& image) const override;
+
+private:
+	bool _isPure;
+	std::string _characterSet;
 };
 
 } // Aztec
