@@ -24,22 +24,9 @@ class DetectorResult;
 namespace DataMatrix {
 
 /**
-* <p>Encapsulates logic that can detect a Data Matrix Code in an image, even if the Data Matrix Code
-* is rotated or skewed, or partially obscured.</p>
-*
-* @author Sean Owen, Axel Waggershauser
-*/
-class Detector
-{
-public:
-	/**
-	* <p>Detects a Data Matrix Code in an image.</p>
-	*
-	* @return {@link DetectorResult} encapsulating results of detecting a Data Matrix Code
-	* @throws NotFoundException if no Data Matrix Code can be found
-	*/
-	static DetectorResult Detect(const BitMatrix& image, bool tryHarder, bool tryRotate, bool isPure);
-};
+ * @brief Detects a Data Matrix symbol in an image.
+ */
+DetectorResult Detect(const BitMatrix& image, bool tryHarder, bool tryRotate, bool isPure);
 
 } // DataMatrix
 } // ZXing
