@@ -17,6 +17,7 @@
 */
 
 #include "Reader.h"
+#include <string>
 
 namespace ZXing {
 
@@ -32,6 +33,7 @@ namespace DataMatrix {
 class Reader : public ZXing::Reader
 {
 	bool _tryRotate, _tryHarder, _isPure;
+	std::string _characterSet;
 public:
 	explicit Reader(const DecodeHints& hints);
 	Result decode(const BinaryBitmap& image) const override;
