@@ -16,12 +16,12 @@
 */
 
 #include "ODCode128Reader.h"
-#include "ODCode128Patterns.h"
-#include "Result.h"
+
 #include "BitArray.h"
 #include "DecodeHints.h"
+#include "ODCode128Patterns.h"
+#include "Result.h"
 #include "ZXContainerAlgorithms.h"
-#include "ZXStrConvWorkaround.h"
 
 #include <array>
 #include <cassert>
@@ -32,8 +32,7 @@
 #include <utility>
 #include <vector>
 
-namespace ZXing {
-namespace OneD {
+namespace ZXing::OneD {
 
 static const float MAX_AVG_VARIANCE = 0.25f;
 static const float MAX_INDIVIDUAL_VARIANCE = 0.7f;
@@ -57,6 +56,7 @@ class Raw2TxtDecoder
 {
 	int codeSet = 0;
 	bool _convertFNC1 = false;
+	bool _readerInit = false;
 	std::string txt;
 	size_t lastTxtSize = 0;
 
@@ -105,9 +105,11 @@ public:
 			switch (code) {
 			case CODE_FNC_1: fnc1(); break;
 			case CODE_FNC_2:
-			case CODE_FNC_3:
 				// do nothing?
 				break;
+			case CODE_FNC_3:
+				_readerInit = true; // Can occur anywhere in the symbol (ISO/IEC 15417:2007 4.3.4.2 (c))
+				break;
 			case CODE_SHIFT:
 				if (shift)
 					return false; // two shifts in a row make no sense
@@ -156,6 +158,8 @@ public:
 		// be a printable character).
 		return txt.substr(0, lastTxtSize);
 	}
+
+	bool readerInit() const { return _readerInit; }
 };
 
 template <typename C>
@@ -173,84 +177,11 @@ static int DetectStartCode(const C& c)
 	return bestVariance < MAX_AVG_VARIANCE ? bestCode : 0;
 }
 
-static BitArray::Range
-FindStartPattern(const BitArray& row, int* startCode)
-{
-	assert(startCode != nullptr);
-
-	using Counters = std::vector<int>;
-	Counters counters(Code128::CODE_PATTERNS[CODE_START_A].size());
-
-	return RowReader::FindPattern(
-	    row.getNextSet(row.begin()), row.end(), counters,
-		[&row, startCode](BitArray::Iterator begin, BitArray::Iterator end, const Counters& counters) -> bool {
-			// Look for whitespace before start pattern, >= 50% of width of start pattern
-			if (!row.hasQuiteZone(begin, static_cast<int>(-(end-begin)/2)))
-				return false;
-			return (*startCode = DetectStartCode(counters));
-	    });
-}
-
 Code128Reader::Code128Reader(const DecodeHints& hints) :
 	_convertFNC1(hints.assumeGS1())
 {
 }
 
-Result
-Code128Reader::decodeRow(int rowNumber, const BitArray& row, std::unique_ptr<DecodingState>&) const
-{
-	int startCode = 0;
-	auto range = FindStartPattern(row, &startCode);
-	if (!range) {
-		return Result(DecodeStatus::NotFound);
-	}
-
-	int xStart = static_cast<int>(range.begin - row.begin());
-	ByteArray rawCodes;
-	rawCodes.reserve(20);
-	std::vector<int> counters(6, 0);
-	Raw2TxtDecoder raw2txt(startCode, _convertFNC1);
-
-	rawCodes.push_back(static_cast<uint8_t>(startCode));
-
-	while (true) {
-		range = RecordPattern(range.end, row.end(), counters);
-		if (!range)
-			return Result(DecodeStatus::NotFound);
-
-		// Decode another code from image
-		int code = RowReader::DecodeDigit(counters, Code128::CODE_PATTERNS, MAX_AVG_VARIANCE, MAX_INDIVIDUAL_VARIANCE);
-		if (code == -1)
-			return Result(DecodeStatus::NotFound);
-		if (code == CODE_STOP)
-			break;
-		if (code >= CODE_START_A)
-			return Result(DecodeStatus::FormatError);
-		if (!raw2txt.decode(code))
-			return Result(DecodeStatus::FormatError);
-
-		rawCodes.push_back(static_cast<uint8_t>(code));
-	}
-
-	// Check for ample whitespace following pattern, but, to do this we first need to remember that
-	// we fudged decoding CODE_STOP since it actually has 7 bars, not 6. There is a black bar left
-	// to read off. Would be slightly better to properly read. Here we just skip it:
-	range.end = row.getNextUnset(range.end);
-	if (rawCodes.empty() || !row.hasQuiteZone(range.end, range.size() / 2))
-		return Result(DecodeStatus::NotFound);
-
-	int checksum = rawCodes.front();
-	for (int i = 1; i < Size(rawCodes) - 1; ++i)
-		checksum += i * rawCodes[i];
-	// the last code is the checksum:
-	if (checksum % 103 != rawCodes.back()) {
-		return Result(DecodeStatus::ChecksumError);
-	}
-
-	int xStop = static_cast<int>(range.end - row.begin() - 1);
-	return Result(raw2txt.text(), rowNumber, xStart, xStop, BarcodeFormat::CODE_128, std::move(rawCodes));
-}
-
 // all 3 start patterns share the same 2-1-1 prefix
 constexpr auto START_PATTERN_PREFIX = FixedPattern<3, 4>{2, 1, 1};
 constexpr int CHAR_LEN = 6;
@@ -351,8 +282,8 @@ Result Code128Reader::decodePattern(int rowNumber, const PatternView& row, std::
 		return Result(DecodeStatus::ChecksumError);
 
 	int xStop = next.pixelsTillEnd();
-	return Result(raw2txt.text(), rowNumber, xStart, xStop, BarcodeFormat::CODE_128, std::move(rawCodes));
+	return Result(raw2txt.text(), rowNumber, xStart, xStop, BarcodeFormat::Code128, std::move(rawCodes),
+				  raw2txt.readerInit());
 }
 
-} // OneD
-} // ZXing
+} // namespace ZXing::OneD
