@@ -16,14 +16,14 @@
 */
 
 #include "ODUPCEWriter.h"
+
 #include "ODUPCEANCommon.h"
 #include "ODWriterHelper.h"
 
 #include <stdexcept>
 #include <vector>
 
-namespace ZXing {
-namespace OneD {
+namespace ZXing::OneD {
 
 static const int CODE_WIDTH = 3 + // start guard
                               (7 * 6) + // bars
@@ -58,5 +58,4 @@ UPCEWriter::encode(const std::wstring& contents, int width, int height) const
 	return WriterHelper::RenderResult(result, width, height, _sidesMargin >= 0 ? _sidesMargin : 9);
 }
 
-} // OneD
-} // ZXing
+} // namespace ZXing::OneD
