@@ -309,7 +309,7 @@ static const short* EC_COEFFICIENTS[] = {EC_COEFFICIENTS_L0, EC_COEFFICIENTS_L1,
 * @param errorCorrectionLevel the error correction level (0-8)
 * @return the number of codewords generated for error correction
 */
-static inline int GetErrorCorrectionCodewordCount(int errorCorrectionLevel)
+static int GetErrorCorrectionCodewordCount(int errorCorrectionLevel)
 {
 	return 1 << (errorCorrectionLevel + 1);
 }
@@ -325,7 +325,7 @@ static void GenerateErrorCorrection(std::vector<int>& dataCodewords, int errorCo
 {
 	int k = GetErrorCorrectionCodewordCount(errorCorrectionLevel);
 	std::vector<int> e(k, 0);
-	int sld = (int)dataCodewords.size();
+	int sld = Size(dataCodewords);
 	for (int i = 0; i < sld; i++) {
 		int t1 = (dataCodewords[i] + e[k - 1]) % 929;
 		int t2;
@@ -496,7 +496,6 @@ static void DetermineDimensions(int minCols, int maxCols, int minRows, int maxRo
 		if (rows < minRows) {
 			outCols = minCols;
 			outRows = minRows;
-			haveDimension = true;
 		}
 		else {
 			throw std::invalid_argument("Unable to fit message in columns");
