@@ -247,13 +247,13 @@ static bool AdjustBoundingBox(Nullable<DetectionResultColumn>& rowIndicatorColum
 		missingStartRows--;
 	}
 	int missingEndRows = 0;
-	for (int row = (int)rowHeights.size() - 1; row >= 0; row--) {
+	for (int row = Size(rowHeights) - 1; row >= 0; row--) {
 		missingEndRows += maxRowHeight - rowHeights[row];
 		if (rowHeights[row] > 0) {
 			break;
 		}
 	}
-	for (int row = (int)codewords.size() - 1; missingEndRows > 0 && codewords[row] == nullptr; row--) {
+	for (int row = Size(codewords) - 1; missingEndRows > 0 && codewords[row] == nullptr; row--) {
 		missingEndRows--;
 	}
 	BoundingBox box;
@@ -335,7 +335,7 @@ static std::vector<std::vector<BarcodeValue>> CreateBarcodeMatrix(DetectionResul
 				if (codeword != nullptr) {
 					int rowNumber = codeword.value().rowNumber();
 					if (rowNumber >= 0) {
-						if (rowNumber >= (int)barcodeMatrix.size()) {
+						if (rowNumber >= Size(barcodeMatrix)) {
 							// We have more rows than the barcode metadata allows for, ignore them.
 							continue;
 						}
@@ -543,7 +543,7 @@ bool DecodeErrorCorrection(std::vector<int>& received, int numECCodewords, const
 */
 static bool CorrectErrors(std::vector<int>& codewords, const std::vector<int>& erasures, int numECCodewords, int& errorCount)
 {
-	if ((int)erasures.size() > numECCodewords / 2 + MAX_ERRORS ||
+	if (Size(erasures) > numECCodewords / 2 + MAX_ERRORS ||
 		numECCodewords < 0 ||
 		numECCodewords > MAX_EC_CODEWORDS) {
 		// Too many errors or EC Codewords is corrupted
@@ -566,13 +566,13 @@ static bool VerifyCodewordCount(std::vector<int>& codewords, int numECCodewords)
 	// codewords in the symbol, including the Symbol Length Descriptor itself, data codewords and pad
 	// codewords, but excluding the number of error correction codewords.
 	int numberOfCodewords = codewords[0];
-	if (numberOfCodewords > (int)codewords.size()) {
+	if (numberOfCodewords > Size(codewords)) {
 		return false;
 	}
 	if (numberOfCodewords == 0) {
 		// Reset to the length of the array - 8 (Allow for at least level 3 Error Correction (8 Error Codewords)
-		if (numECCodewords < (int)codewords.size()) {
-			codewords[0] = (int)codewords.size() - numECCodewords;
+		if (numECCodewords < Size(codewords)) {
+			codewords[0] = Size(codewords) - numECCodewords;
 		}
 		else {
 			return false;
@@ -581,7 +581,8 @@ static bool VerifyCodewordCount(std::vector<int>& codewords, int numECCodewords)
 	return true;
 }
 
-static DecoderResult DecodeCodewords(std::vector<int>& codewords, int ecLevel, const std::vector<int>& erasures)
+DecoderResult DecodeCodewords(std::vector<int>& codewords, int ecLevel, const std::vector<int>& erasures,
+							  const std::string& characterSet)
 {
 	if (codewords.empty()) {
 		return DecodeStatus::FormatError;
@@ -596,7 +597,7 @@ static DecoderResult DecodeCodewords(std::vector<int>& codewords, int ecLevel, c
 		return DecodeStatus::FormatError;
 
 	// Decode the codewords
-	auto result = DecodedBitStreamParser::Decode(codewords, ecLevel);
+	auto result = DecodedBitStreamParser::Decode(codewords, ecLevel, characterSet);
 	if (result.isValid()) {
 		result.setErrorsCorrected(correctedErrorsCount);
 		result.setErasures(Size(erasures));
@@ -618,7 +619,9 @@ static DecoderResult DecodeCodewords(std::vector<int>& codewords, int ecLevel, c
 * @param ambiguousIndexValues two dimensional array that contains the ambiguous values. The first dimension must
 * be the same length as the ambiguousIndexes array
 */
-static DecoderResult CreateDecoderResultFromAmbiguousValues(int ecLevel, std::vector<int>& codewords, const std::vector<int>& erasureArray, const std::vector<int>& ambiguousIndexes, const std::vector<std::vector<int>>& ambiguousIndexValues)
+static DecoderResult CreateDecoderResultFromAmbiguousValues(int ecLevel, std::vector<int>& codewords,
+	const std::vector<int>& erasureArray, const std::vector<int>& ambiguousIndexes,
+	const std::vector<std::vector<int>>& ambiguousIndexValues, const std::string& characterSet)
 {
 	std::vector<int> ambiguousIndexCount(ambiguousIndexes.size(), 0);
 
@@ -627,7 +630,7 @@ static DecoderResult CreateDecoderResultFromAmbiguousValues(int ecLevel, std::ve
 		for (size_t i = 0; i < ambiguousIndexCount.size(); i++) {
 			codewords[ambiguousIndexes[i]] = ambiguousIndexValues[i][ambiguousIndexCount[i]];
 		}
-		auto result = DecodeCodewords(codewords, ecLevel, erasureArray);
+		auto result = DecodeCodewords(codewords, ecLevel, erasureArray, characterSet);
 		if (result.errorCode() != DecodeStatus::ChecksumError) {
 			return result;
 		}
@@ -636,7 +639,7 @@ static DecoderResult CreateDecoderResultFromAmbiguousValues(int ecLevel, std::ve
 			return DecodeStatus::ChecksumError;
 		}
 		for (size_t i = 0; i < ambiguousIndexCount.size(); i++) {
-			if (ambiguousIndexCount[i] < (int)ambiguousIndexValues[i].size() - 1) {
+			if (ambiguousIndexCount[i] < Size(ambiguousIndexValues[i]) - 1) {
 				ambiguousIndexCount[i]++;
 				break;
 			}
@@ -652,7 +655,7 @@ static DecoderResult CreateDecoderResultFromAmbiguousValues(int ecLevel, std::ve
 }
 
 
-static DecoderResult CreateDecoderResult(DetectionResult& detectionResult)
+static DecoderResult CreateDecoderResult(DetectionResult& detectionResult, const std::string& characterSet)
 {
 	auto barcodeMatrix = CreateBarcodeMatrix(detectionResult);
 	if (!AdjustCodewordCount(detectionResult, barcodeMatrix)) {
@@ -678,7 +681,8 @@ static DecoderResult CreateDecoderResult(DetectionResult& detectionResult)
 			}
 		}
 	}
-	return CreateDecoderResultFromAmbiguousValues(detectionResult.barcodeECLevel(), codewords, erasures, ambiguousIndexesList, ambiguousIndexValues);
+	return CreateDecoderResultFromAmbiguousValues(detectionResult.barcodeECLevel(), codewords, erasures,
+												  ambiguousIndexesList, ambiguousIndexValues, characterSet);
 }
 
 
@@ -689,7 +693,7 @@ static DecoderResult CreateDecoderResult(DetectionResult& detectionResult)
 DecoderResult
 ScanningDecoder::Decode(const BitMatrix& image, const Nullable<ResultPoint>& imageTopLeft, const Nullable<ResultPoint>& imageBottomLeft,
 	const Nullable<ResultPoint>& imageTopRight, const Nullable<ResultPoint>& imageBottomRight,
-	int minCodewordWidth, int maxCodewordWidth)
+	int minCodewordWidth, int maxCodewordWidth, const std::string& characterSet)
 {
 	BoundingBox boundingBox;
 	if (!BoundingBox::Create(image.width(), image.height(), imageTopLeft, imageBottomLeft, imageTopRight, imageBottomRight, boundingBox)) {
@@ -750,7 +754,7 @@ ScanningDecoder::Decode(const BitMatrix& image, const Nullable<ResultPoint>& ima
 			}
 		}
 	}
-	return CreateDecoderResult(detectionResult);
+	return CreateDecoderResult(detectionResult, characterSet);
 }
 
 } // Pdf417
