@@ -24,24 +24,9 @@ class BitMatrix;
 namespace QRCode {
 
 /**
-* <p>Encapsulates logic that can detect a QR Code in an image, even if the QR Code
-* is rotated or skewed, or partially obscured.</p>
-*
-* @author Sean Owen
-*/
-class Detector
-{
-public:
-	/**
-	* <p>Detects a QR Code in an image.</p>
-	*
-	* @param hints optional hints to detector
-	* @return {@link DetectorResult} encapsulating results of detecting a QR Code
-	* @throws NotFoundException if QR Code cannot be found
-	* @throws FormatException if a QR Code cannot be decoded
-	*/
-	static DetectorResult Detect(const BitMatrix& image, bool tryHarder, bool isPure);
-};
+ * @brief Detects a QR Code in an image.
+ */
+DetectorResult Detect(const BitMatrix& image, bool tryHarder, bool isPure);
 
 } // QRCode
 } // ZXing
