@@ -16,22 +16,21 @@
 */
 
 #include "QRReader.h"
-#include "QRDecoder.h"
-#include "QRDetector.h"
-#include "QRDecoderMetadata.h"
-#include "Result.h"
-#include "DecoderResult.h"
-#include "DetectorResult.h"
-#include "ResultPoint.h"
-#include "DecodeHints.h"
+
 #include "BinaryBitmap.h"
 #include "BitMatrix.h"
-#include "ZXNumeric.h"
+#include "DecodeHints.h"
+#include "DecoderResult.h"
+#include "DetectorResult.h"
+#include "QRDecoder.h"
+#include "QRDecoderMetadata.h"
+#include "QRDetector.h"
+#include "Result.h"
+#include "ResultPoint.h"
 
 #include <utility>
 
-namespace ZXing {
-namespace QRCode {
+namespace ZXing::QRCode {
 
 Reader::Reader(const DecodeHints& hints)
 	: _tryHarder(hints.tryHarder()), _isPure(hints.isPure()), _charset(hints.characterSet())
@@ -46,18 +45,17 @@ Reader::decode(const BinaryBitmap& image) const
 		return Result(DecodeStatus::NotFound);
 	}
 
-	auto detectorResult = Detector::Detect(*binImg, _tryHarder, _isPure);
+	auto detectorResult = Detect(*binImg, _tryHarder, _isPure);
 	if (!detectorResult.isValid())
 		return Result(DecodeStatus::NotFound);
 
-	auto decoderResult = Decoder::Decode(detectorResult.bits(), _charset);
+	auto decoderResult = Decode(detectorResult.bits(), _charset);
 	auto position = detectorResult.position();
 
 	// TODO: report the information that the symbol was mirrored back to the caller
 	//bool isMirrored = decoderResult.extra() && static_cast<DecoderMetadata*>(decoderResult.extra().get())->isMirrored();
 
-	return Result(std::move(decoderResult), std::move(position), BarcodeFormat::QR_CODE);
+	return Result(std::move(decoderResult), std::move(position), BarcodeFormat::QRCode);
 }
 
-} // QRCode
-} // ZXing
+} // namespace ZXing::QRCode
