@@ -16,16 +16,14 @@
 */
 
 #include "QRVersion.h"
-#include "QRECB.h"
+
 #include "BitHacks.h"
 #include "BitMatrix.h"
+#include "QRECB.h"
 
 #include <limits>
 
-namespace ZXing {
-namespace QRCode {
-
-namespace {
+namespace ZXing::QRCode {
 
 	/**
 	* See ISO 18004:2006 Annex D.
@@ -41,9 +39,6 @@ namespace {
 		0x2542E, 0x26A64, 0x27541, 0x28C69
 	};
 
-
-} // anonymous
-
 const Version *
 Version::AllVersions()
 {
@@ -356,11 +351,10 @@ Version::DecodeVersionInformation(int versionBits)
 /**
 * See ISO 18004:2006 Annex E
 */
-void
-Version::buildFunctionPattern(BitMatrix& bitMatrix) const
+BitMatrix Version::buildFunctionPattern() const
 {
 	int dimension = dimensionForVersion();
-	bitMatrix = BitMatrix(dimension, dimension);
+	BitMatrix bitMatrix(dimension, dimension);
 
 	// Top left finder pattern + separator + format
 	bitMatrix.setRegion(0, 0, 9, 9);
@@ -375,7 +369,7 @@ Version::buildFunctionPattern(BitMatrix& bitMatrix) const
 		int i = _alignmentPatternCenters[x] - 2;
 		for (size_t y = 0; y < max; ++y) {
 			if ((x == 0 && (y == 0 || y == max - 1)) || (x == max - 1 && y == 0)) {
-				// No alignment patterns near the three finder paterns
+				// No alignment patterns near the three finder patterns
 				continue;
 			}
 			bitMatrix.setRegion(_alignmentPatternCenters[y] - 2, i, 5, 5);
@@ -393,7 +387,8 @@ Version::buildFunctionPattern(BitMatrix& bitMatrix) const
 		// Version info, bottom left
 		bitMatrix.setRegion(0, dimension - 11, 6, 3);
 	}
+
+	return bitMatrix;
 }
 
-} // QRCode
-} // ZXing
+} // namespace ZXing::QRCode
