@@ -14,23 +14,24 @@
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
-#include "aztec/AZEncoder.h"
-#include "aztec/AZDetectorResult.h"
-#include "aztec/AZDecoder.h"
-#include "aztec/AZWriter.h"
-#include "DecoderResult.h"
+
 #include "BitMatrix.h"
-#include "PseudoRandom.h"
 #include "CharacterSet.h"
-#include "TextEncoder.h"
+#include "DecoderResult.h"
+#include "PseudoRandom.h"
 #include "TextDecoder.h"
+#include "TextEncoder.h"
+#include "aztec/AZDecoder.h"
+#include "aztec/AZDetectorResult.h"
+#include "aztec/AZEncoder.h"
+#include "aztec/AZWriter.h"
 
 #include <algorithm>
 #include <utility>
 
 namespace testing {
 	namespace internal {
-		inline bool operator==(const std::string& a, const std::wstring& b) {
+		bool operator==(const std::string& a, const std::wstring& b) {
 			return a.length() == b.length() && std::equal(a.begin(), a.end(), b.begin());
 		}
 	}
@@ -42,14 +43,21 @@ using namespace ZXing;
 
 namespace {
 
+
+	// Shorthand to call Decode()
+	static DecoderResult parse(BitMatrix&& bits, bool compact, int nbDatablocks, int nbLayers)
+	{
+		return Aztec::Decoder::Decode({{std::move(bits), {}}, compact, nbDatablocks, nbLayers, false /*readerInit*/},
+									  "");
+	}
+
 	void TestEncodeDecode(const std::string& data, bool compact, int layers) {
 
 		Aztec::EncodeResult aztec = Aztec::Encoder::Encode(data, 25, Aztec::Encoder::DEFAULT_AZTEC_LAYERS);
 		ASSERT_EQ(aztec.compact, compact) << "Unexpected symbol format (compact)";
 		ASSERT_EQ(aztec.layers, layers) << "Unexpected nr. of layers";
 
-		DecoderResult res =
-			Aztec::Decoder::Decode({{aztec.matrix.copy(), {}}, aztec.compact, aztec.codeWords, aztec.layers});
+		DecoderResult res = parse(aztec.matrix.copy(), aztec.compact, aztec.codeWords, aztec.layers);
 		ASSERT_EQ(res.isValid(), true);
 		EXPECT_EQ(data, res.text());
 
@@ -69,7 +77,7 @@ namespace {
 		y = random.next(0, matrix.height() - 1);
 		matrix.flip(x, y);
 
-		res = Aztec::Decoder::Decode({{std::move(matrix), {}}, aztec.compact, aztec.codeWords, aztec.layers});
+		res = parse(std::move(matrix), aztec.compact, aztec.codeWords, aztec.layers);
 		ASSERT_EQ(res.isValid(), true);
 		EXPECT_EQ(data, res.text());
 	}
@@ -91,7 +99,7 @@ namespace {
 		EXPECT_EQ(aztec.matrix, matrix);
 
 		std::wstring expectedData = TextDecoder::ToUnicode(textBytes, CharacterSet::ISO8859_1);
-		DecoderResult res = Aztec::Decoder::Decode({{matrix.copy(), {}}, aztec.compact, aztec.codeWords, aztec.layers});
+		DecoderResult res = parse(matrix.copy(), aztec.compact, aztec.codeWords, aztec.layers);
 		EXPECT_EQ(res.isValid(), true);
 		EXPECT_EQ(res.text(), expectedData);
 
@@ -108,7 +116,7 @@ namespace {
 				: matrix.height() - 1 - random.next(0, aztec.layers * 2 - 1);
 			matrix.flip(x, y);
 		}
-		res = Aztec::Decoder::Decode({{std::move(matrix), {}}, aztec.compact, aztec.codeWords, aztec.layers});
+		res = parse(std::move(matrix), aztec.compact, aztec.codeWords, aztec.layers);
 		EXPECT_EQ(res.isValid(), true);
 		EXPECT_EQ(res.text(), expectedData);
 	}
@@ -228,8 +236,7 @@ TEST(AZEncodeDecodeTest, AztecWriter)
 		
 	// Test AztecWriter defaults
 	std::wstring data = L"In ut magna vel mauris malesuada";
-	Aztec::Writer writer;
-	BitMatrix matrix = writer.encode(data, 0, 0);
+	BitMatrix matrix = Aztec::Writer().encode(data, 0, 0);
 	Aztec::EncodeResult aztec =
 		Aztec::Encoder::Encode(TextEncoder::FromUnicode(data, CharacterSet::ISO8859_1),
 							   Aztec::Encoder::DEFAULT_EC_PERCENT, Aztec::Encoder::DEFAULT_AZTEC_LAYERS);
