@@ -29,6 +29,7 @@ struct ReadResult
 	std::string format;
 	std::wstring text;
 	std::string error;
+	ZXing::Position position;
 };
 
 ReadResult readBarcodeFromImage(int bufferPtr, int bufferLength, bool tryHarder, std::string format)
@@ -51,7 +52,7 @@ ReadResult readBarcodeFromImage(int bufferPtr, int bufferLength, bool tryHarder,
 
 		auto result = ReadBarcode({buffer.get(), width, height, ImageFormat::RGBX}, hints);
 		if (result.isValid()) {
-			return { ToString(result.format()), result.text(), "" };
+			return { ToString(result.format()), result.text(), "", result.position() };
 		}
 	}
 	catch (const std::exception& e) {
@@ -76,7 +77,7 @@ ReadResult readBarcodeFromPixmap(int bufferPtr, int imgWidth, int imgHeight, boo
 			ReadBarcode({reinterpret_cast<uint8_t*>(bufferPtr), imgWidth, imgHeight, ImageFormat::RGBX}, hints);
 
 		if (result.isValid()) {
-			return { ToString(result.format()), result.text(), "" };
+			return { ToString(result.format()), result.text(), "", result.position() };
 		}
 	}
 	catch (const std::exception& e) {
@@ -93,10 +94,23 @@ EMSCRIPTEN_BINDINGS(BarcodeReader)
 	using namespace emscripten;
 
 	value_object<ReadResult>("ReadResult")
-	        .field("format", &ReadResult::format)
-	        .field("text", &ReadResult::text)
-	        .field("error", &ReadResult::error)
-	        ;
+			.field("format", &ReadResult::format)
+			.field("text", &ReadResult::text)
+			.field("error", &ReadResult::error)
+			.field("position", &ReadResult::position)
+			;
+
+	value_object<ZXing::PointI>("Point")
+			.field("x", &ZXing::PointI::x)
+			.field("y", &ZXing::PointI::y)
+			;
+
+	value_object<ZXing::Position>("Position")
+			.field("topLeft", emscripten::index<0>())
+			.field("topRight", emscripten::index<1>())
+			.field("bottomRight", emscripten::index<2>())
+			.field("bottomLeft", emscripten::index<3>())
+			;
 
 	function("readBarcodeFromImage", &readBarcodeFromImage);
 	function("readBarcodeFromPixmap", &readBarcodeFromPixmap);
