@@ -37,11 +37,10 @@ public enum class BarcodeType : int {
 	RSS_14,
 	RSS_EXPANDED,
 	UPC_A,
-	UPC_E,
-	UPC_EAN_EXTENSION
+	UPC_E
 };
 
-class MultiFormatReader;
+class DecodeHints;
 ref class ReadResult;
 
 public ref class BarcodeReader sealed
@@ -61,7 +60,7 @@ private:
 	static BarcodeFormat ConvertRuntimeToNative(BarcodeType type);
 	static BarcodeType ConvertNativeToRuntime(BarcodeFormat format);
 
-	std::unique_ptr<MultiFormatReader> m_reader;
+	std::unique_ptr<DecodeHints> m_hints;
 };
 
 } // ZXing
